@@ -1,11 +1,24 @@
 context("check_response")
 
-test_that("check_response returns an error", {
-  skip_on_cran()
-  skip_on_ci()
-  skip_if_government_down()
-  skip_if_noaa_ncdc_down()
+skip_on_cran()
+skip_on_ci()
+skip_if_government_down()
+skip_if_noaa_ncdc_down()
 
+test_that("check_response works correctly on bad response content-type", {
+  skip_if_not_installed("webmockr")
+  webmockr::enable()
+  webmockr::stub_request("get", 'https://www.ncdc.noaa.gov/cdo-web/api/v2/data?datasetid=GHCND&startdate=2013-10-01&enddate=2013-12-01&limit=25&includemetadata=TRUE&stationid=GHCND%3AUSW00014895') %>%
+    webmockr::to_return(headers = list(`content-type` = "application/xml"))
+  expect_error(
+    ncdc(datasetid='GHCND', stationid='GHCND:USW00014895',
+       startdate = '2013-10-01', enddate = '2013-12-01'),
+    "wrong response type"
+  )
+  webmockr::disable()
+})
+
+test_that("check_response returns an error", {
   # Sys.sleep(time = 0.5)
   expect_warning(ncdc_locs_cats(startdate='2100-01-01'), "no data found")
   # Sys.sleep(time = 0.5)
@@ -22,11 +35,6 @@ test_that("check_response returns an error", {
 })
 
 test_that("check_response returns the correct error messages", {
-  skip_on_cran()
-  skip_on_ci()
-  skip_if_government_down()
-  skip_if_noaa_ncdc_down()
-  
   # no data found
   # Sys.sleep(time = 0.5)
   expect_warning(ncdc_locs_cats(startdate='2100-01-01'), "no data found")
